@@ -266,6 +266,7 @@ exo_tree_view_button_press_event (GtkWidget      *widget,
   gboolean          result;
   GList            *selected_paths = NULL;
   GList            *lp;
+  gpointer          drag_data;
 
   /* by default we won't emit "row-activated" on button-release-events */
   tree_view->priv->button_release_activates = FALSE;
@@ -334,7 +335,7 @@ exo_tree_view_button_press_event (GtkWidget      *widget,
       if (G_LIKELY (path == NULL || !gtk_tree_selection_path_is_selected (selection, path)))
         {
           /* need to disable drag and drop because we're rubberbanding now */
-          gpointer drag_data = g_object_get_data (G_OBJECT (tree_view), I_("gtk-site-data"));
+          drag_data = g_object_get_data (G_OBJECT (tree_view), I_("gtk-site-data"));
           if (G_LIKELY (drag_data != NULL))
             {
               g_signal_handlers_block_matched (G_OBJECT (tree_view),
@@ -364,14 +365,7 @@ exo_tree_view_button_press_event (GtkWidget      *widget,
       && path != NULL && gtk_tree_selection_path_is_selected (selection, path))
     {
       /* check if we have to restore paths */
-      if (G_LIKELY (selection->user_func == (GtkTreeSelectionFunc) exo_noop_false))
-        {
-          /* just reset the select function (previously set to exo_noop_false),
-           * there's no clean way to do this, so what the heck.
-           */
-          selection->user_func = NULL;
-        }
-      else
+      if (G_LIKELY (selection->user_func != (GtkTreeSelectionFunc) exo_noop_false))
         {
           /* select all previously selected paths */
           for (lp = selected_paths; lp != NULL; lp = lp->next)
@@ -379,6 +373,15 @@ exo_tree_view_button_press_event (GtkWidget      *widget,
         }
     }
 
+  /* see bug http://bugzilla.xfce.org/show_bug.cgi?id=6230 for more information */
+  if (G_LIKELY (selection->user_func == (GtkTreeSelectionFunc) exo_noop_false))
+    {
+      /* just reset the select function (previously set to exo_noop_false),
+       * there's no clean way to do this, so what the heck.
+       */
+      selection->user_func = NULL;
+    }
+
   /* release the path (if any) */
   if (G_LIKELY (path != NULL))
     gtk_tree_path_free (path);
@@ -400,6 +403,7 @@ exo_tree_view_button_release_event (GtkWidget      *widget,
   GtkTreeSelection  *selection;
   GtkTreePath       *path;
   ExoTreeView       *tree_view = EXO_TREE_VIEW (widget);
+  gpointer           drag_data;
 
   /* verify that the release event is for the internal tree view window */
   if (G_LIKELY (event->window == gtk_tree_view_get_bin_window (GTK_TREE_VIEW (tree_view))))
@@ -447,7 +451,7 @@ exo_tree_view_button_release_event (GtkWidget      *widget,
   /* check if we need to re-enable drag and drop */
   if (G_LIKELY (tree_view->priv->button_release_unblocks_dnd))
     {
-      gpointer drag_data = g_object_get_data (G_OBJECT (tree_view), I_("gtk-site-data"));
+      drag_data = g_object_get_data (G_OBJECT (tree_view), I_("gtk-site-data"));
       if (G_LIKELY (drag_data != NULL))
         {
           g_signal_handlers_unblock_matched (G_OBJECT (tree_view),
